# Models of Separation Logics for a simple imperative lambda-calculus

This archive contains definitions and proofs of soundness for several
simple Separation Logics.

One such Separation Logic is equipped with read-only permissions,
as described in the paper
__Temporary Read-Only Permissions for Separation Logic__
by Arthur Charguéraud and François Pottier
(ESOP 2017).

Another Separation Logic is equipped with time credits,
as described in the paper
__Verifying the Correctness and Amortized Complexity
of a Union-Find Implementation
in Separation Logic with Time Credits__
by Arthur Charguéraud and François Pottier
(in preparation).

Some aspects of these logics are shared, while some are duplicated.
Ideally, there should be less duplication; this is work in progress.

# Organisation of the subdirectories:

* The subdirectory __TLC__
  contains Charguéraud's general-purpose Coq library.

* The subdirectory __model__
  contains definitions and proofs about Separation Logic.

 * The file __ModelState.v__
   defines a representation of finite maps, used to represent stores.

 * The file __ModelLambda.v__
   defines the syntax and semantics of an imperative lambda-calculus.

 * The file __ModelSepFunctor.v__
   contains a functor for building derived properties 
   of a Separation Logic.

 * The file __ModelSepBasic.v__
   instantiates the functor to derive 
   a plain Separation Logic,
   and establishes the soundness of this logic.

 * The file __ModelSepCredits.v__
   instantiates the functor to derive a 
   Separation Logic with Time Credits,
   and establishes the soundness of this logic.

 * The file __ModelSepRO.v__
   instantiates the functor to derive a 
   Separation Logic with Temporary Read-Only Permissions.
   and establishes the soundness of this logic.

 * The file __ModelCF.v__
   defines characteristic formulae for
   plain Separation Logic and proves them sound.

 * The file __ModelCFCredits.v__
   defines characteristic formulae for
   Separation Logic with Time Credits
   and proves them sound.

